@@ -22,6 +22,7 @@ from .aesutils import get_raw_aes_key as raw_aes_key
 from .aesutils import padding_ansix923 as aes_padding_ansix923
 from .aesutils import padding_iso10126 as aes_padding_iso10126
 from .aesutils import padding_pkcs5 as aes_padding_pkcs5
+from .listutils import first
 
 class DecryptFailed(RuntimeError):
     pass
@@ -103,9 +104,9 @@ class CipherBase(object):
     default_decrypt_force_bytes = True
     default_encrypt_kwargs = {}
     default_decrypt_kwargs = {}
-    default_result_encoder = RawDataEncoder()
-    default_force_text = False
-    default_text_encoding = "utf-8"
+    default_result_encoder = None
+    default_force_text = None
+    default_text_encoding = None
     default_cipher_core = None
 
     def get_defaults(self):
@@ -123,18 +124,36 @@ class CipherBase(object):
             defaults.update(getattr(self, "defaults"))
         return defaults
 
-    def __init__(self, password=None, encrypt_force_bytes=None, decrypt_force_bytes=None, encrypt_kwargs=None, decrypt_kwargs=None, result_encoder=None, force_text=None, text_encoding=None, cipher_core=None, encrypt=None, decrypt=None, **kwargs):
+    def __init__(self, 
+            password=None,
+            encrypt_force_bytes=None,
+            decrypt_force_bytes=None,
+            encrypt_kwargs=None,
+            decrypt_kwargs=None,
+            result_encoder=None,
+            force_text=None,
+            text_encoding=None,
+            cipher_core=None,
+            encrypt=None,
+            decrypt=None,
+            kwargs=None,
+            **extra_kwargs,
+            ):
+        kwargs = kwargs or {}
         defaults = self.get_defaults()
         self.password = password
-        self.encrypt_force_bytes = encrypt_force_bytes is None and defaults["encrypt_force_bytes"] or encrypt_force_bytes
-        self.decrypt_force_bytes = decrypt_force_bytes is None and defaults["decrypt_force_bytes"] or decrypt_force_bytes
-        self.encrypt_kwargs = encrypt_kwargs is None and defaults["encrypt_kwargs"] or encrypt_kwargs or {}
-        self.decrypt_kwargs = decrypt_kwargs is None and defaults["decrypt_kwargs"] or decrypt_kwargs or {}
-        self.result_encoder = result_encoder is None and defaults["result_encoder"] or result_encoder
-        self.force_text = force_text is None and defaults["force_text"] or force_text
-        self.text_encoding = text_encoding is None and defaults["text_encoding"] or text_encoding
-        self.cipher_core = cipher_core is None and defaults["cipher_core"] or cipher_core
-        self.kwargs = kwargs
+        self.encrypt_force_bytes = first(encrypt_force_bytes, defaults["encrypt_force_bytes"], True)
+        self.decrypt_force_bytes = first(decrypt_force_bytes, defaults["decrypt_force_bytes"], True)
+        self.result_encoder = first(result_encoder, defaults["result_encoder"], RawDataEncoder())
+        self.force_text = first(force_text, defaults["force_text"], False)
+        self.text_encoding = first(text_encoding, defaults["text_encoding"], "utf-8")
+        self.cipher_core = first(cipher_core, defaults["cipher_core"], None)
+        self.encrypt_kwargs = first(encrypt_kwargs, defaults["encrypt_kwargs"], {})
+        self.decrypt_kwargs = first(decrypt_kwargs, defaults["decrypt_kwargs"], {})
+        for key, value in kwargs.items():
+            self.encrypt_kwargs.setdefault(key, value)
+            self.decrypt_kwargs.setdefault(key, value)
+        self.kwargs = extra_kwargs
         self.cipher_instance = None
         if self.cipher_core:
             self.cipher_instance = funcutils.call_with_inject(self.cipher_core, self.kwargs)
