@@ -7,11 +7,12 @@ from urllib.parse import ParseResult
 def get_urlinfo(url):
     return urlparse(url)
 
-def get_url_filename(url):
-    if isinstance(url, ParseResult):
-        info = url
-    else:
-        info = urlparse(url)
+def get_url_filename(url, info=None):
+    if info is None:
+        if isinstance(url, ParseResult):
+            info = url
+        else:
+            info = urlparse(url)
     path = info.path
     filename = os.path.split(path)[1]
     if not filename:
@@ -40,7 +41,7 @@ def download(url, filename):
     size = 0
     with open(filename, "wb") as fobj:
         for data in response.iter_content(4096, False):
-            size += len(size)
+            size += len(data)
             fobj.write(data)
     return size
 
