@@ -195,3 +195,55 @@ def list2dict(thelist, fields):
             result[field_info[0]] = field_info[1]
     return result
 
+
+def compare_execute(old_data, new_data, create_callback, delete_callback, change_callback, old_key, new_key=None):
+    """Compare two list, find elements to create/delete/change, and do callbacks.
+    
+    Returns elements of: (created, deleted, changed).
+    """
+    new_key = new_key or old_key
+
+    old_mapping = {}
+    new_mapping = {}
+
+    for data in old_data:
+        key = old_key(data)
+        old_mapping[key] = data
+    
+    for data in new_data:
+        key = new_key(data)
+        new_mapping[key] = data
+    
+    old_keys = set(list(old_mapping.keys()))
+    new_keys = set(list(new_mapping.keys()))
+
+    create_keys = new_keys - old_keys
+    change_keys = new_keys.intersection(old_keys)
+    delete_keys = old_keys - new_keys
+
+    created = []
+    if create_callback:
+        for key in create_keys:
+            data = new_mapping[key]
+            result = create_callback(key, data)
+            if not result is None:
+                created.append(result)
+        
+    changed = []
+    if change_callback:
+        for key in change_keys:
+            instance = old_mapping[key]
+            data = new_mapping[key]
+            result = change_callback(key, instance, data)
+            if not result is None:
+                changed.append(result)
+    
+    deleted = []
+    if delete_callback:
+        for key in delete_keys:
+            instance = old_mapping[key]
+            result = delete_callback(key, instance)
+            if not result is None:
+                deleted.append(result)
+    
+    return created, deleted, changed
\ No newline at end of file
